@@ -16,13 +16,13 @@
 // along with icd9. If not, see <http://www.gnu.org/licenses/>.
 
 // [[Rcpp::interfaces(r, cpp)]]
-#include <Rinternals.h>
 #include <vector>
 #include <string>
 #include <Rcpp.h>
-#ifdef _OPENMP
+#ifdef ICD9_OPENMP
 #include <omp.h>
 #endif
+#include <Rinternals.h>
 
 // trim one string from right
 std::string trimRight(std::string& s) {
@@ -79,7 +79,7 @@ void printCharVec(CharacterVector cv) {
 // [[Rcpp::export]]
 int getOmpCores() {
 	int cores = 1;
-#ifdef _OPENMP
+#ifdef ICD9_OPENMP
 	cores = omp_get_num_procs();
 #endif
 	return cores;
